# SixAds data science package

This package contains various generic functions that are used in various six ads data science projects.

# Installation

# Modules

## Clean_text

Functions to clean and preprocess textual data 

## Sql 

Functions to read, write and alter information in the database

## Utility

Handy utility functions